$OpenBSD: patch-vorbis_c,v 1.1 2002/01/17 00:25:52 naddy Exp $
--- vorbis.c.orig	Sat Dec  1 03:10:35 2001
+++ vorbis.c	Thu Jan 17 00:34:08 2002
@@ -337,9 +337,8 @@ int st_vorbisstartwrite(ft_t ft) 
 	fprintf(stdout, "Channels: %d  Rate: %ld\n", ft->info.channels,
 		rate);
 
-	/* Set encoding to average bit rate of 128kbps with no min or max */
-	vorbis_encode_init(&ve->vi, ft->info.channels, ft->info.rate,
-			   -1, 128000, -1);
+	/* Set encoding to average bit rate of 112kbps VBR */
+	vorbis_encode_init_vbr(&ve->vi, ft->info.channels, ft->info.rate, 0.3f);
 
 	vorbis_analysis_init(&ve->vd, &ve->vi);
 	vorbis_block_init(&ve->vd, &ve->vb);
